@@ -24,7 +24,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
  *
- * $Id: zaptel.h,v 1.38.2.1 2005/06/15 21:31:22 russell Exp $
+ * $Id: zaptel.h 865 2005-12-17 02:04:05Z kpfleming $
  */
 
 #ifndef _LINUX_ZAPTEL_H
@@ -48,6 +48,12 @@
 #define LINUX26
 #endif
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,10)
+#define zap_pci_module pci_register_driver
+#else
+#define zap_pci_module pci_module_init
+#endif
+
 #include "ecdis.h"
 #include "fasthdlc.h"
 #endif
@@ -145,21 +151,40 @@
 
 #define	RING_DEBOUNCE_TIME	2000	/* 2000 ms ring debounce time */
 
+#ifdef AGGRESSIVE_SUPPRESSOR
+#define ZAPTEL_ECHO_AGGRESSIVE " (aggressive)"
+#else
+#define ZAPTEL_ECHO_AGGRESSIVE
+#endif
+
 #ifdef __KERNEL__
 /* Echo cancellation */
 #if defined(ECHO_CAN_STEVE)
+#define ZAPTEL_ECHO_CANCELLER "STEVE"
 #include "sec.h"
 #elif defined(ECHO_CAN_STEVE2)
+#define ZAPTEL_ECHO_CANCELLER "STEVE2"
 #include "sec-2.h"
 #elif defined(ECHO_CAN_MARK)
+#define ZAPTEL_ECHO_CANCELLER "MARK"
 #include "mec.h"
 #elif defined(ECHO_CAN_MARK2)
+#define ZAPTEL_ECHO_CANCELLER "MARK2"
 #include "mec2.h"
+#elif defined(ECHO_CAN_KB1)
+#define ZAPTEL_ECHO_CANCELLER "KB1"
+#include "kb1ec.h"
+#elif defined(ECHO_CAN_MG2)
+#define ZAPTEL_ECHO_CANCELLER "MG2"
+#include "mg2ec.h"
 #else
+#define ZAPTEL_ECHO_CANCELLER "MARK3"
 #include "mec3.h"
 #endif
 #endif
 
+#define ZT_GET_PARAMS_RETURN_MASTER 0x40000000
+
 typedef struct zt_params
 {
 int channo;		/* Channel number */
@@ -624,6 +649,11 @@ void	*data;
 #define ZT_TONEDETECT _IOW (ZT_CODE, 91, int)
 
 
+/*
+ * Set polarity -- implemented by individual driver.  0 = forward, 1 = reverse
+ */
+#define	ZT_SETPOLARITY		_IOW (ZT_CODE, 92, int)
+
 /* 
  * Startup or Shutdown a span
  */
@@ -797,6 +827,9 @@ struct zt_tone_def {		/* Structure for zone programming */
 /* Timer event -- ping ready */
 #define ZT_EVENT_TIMER_PING		16
 
+/* Ring Begin event */
+#define ZT_EVENT_RINGBEGIN  18
+
 /* Polarity reversal event */
 #define ZT_EVENT_POLARITY  17
 
@@ -893,6 +926,11 @@ struct zt_tone_def {		/* Structure for zone programming */
 #define ZT_MAX_CHANNELS		1024	/* Max, 1024 channels */
 #define ZT_MAX_CONF			1024	/* Max, 1024 conferences */
 
+#ifdef	FXSFLASH
+#define ZT_FXSFLASHMINTIME	450	/* min 450ms */
+#define ZT_FXSFLASHMAXTIME	550	/* max 550ms */
+#endif
+
 #ifdef __KERNEL__
 
 #include <linux/types.h>
@@ -1472,4 +1510,94 @@ static inline short zt_txtone_nextsample(struct zt_chan *ss)
 
 #endif /* __KERNEL__ */
 
+/* The following is for the PCI RADIO interface only. This is specified in
+this file because external processes need to interact with the device.
+Some devices have private functions used for test/diagnostic only, but
+this is not the case here. */
+
+struct zt_radio_stat {
+	unsigned short ctcode_rx;	/* code of currently received CTCSS 
+					   or DCS, 0 for none */
+	unsigned short ctclass;		/* class of currently received CTCSS or
+					    DCS code */
+	unsigned short ctcode_tx;	/* code of currently encoded CTCSS or
+					   DCS, 0 for none */
+	unsigned char radstat;		/* status bits of radio */
+};
+
+#define	RAD_SERIAL_BUFLEN 128
+
+struct zt_radio_param {
+	unsigned short radpar;	/* param identifier */
+	unsigned short index;	/* tone number */
+	int data;		/* param */
+	int data2;		/* param 2 */
+	unsigned char buf[RAD_SERIAL_BUFLEN];
+};
+
+
+/* Get current status IOCTL */
+#define	ZT_RADIO_GETSTAT	_IOR (ZT_CODE, 57, struct zt_radio_stat)
+/* Set a channel parameter IOCTL */
+#define	ZT_RADIO_SETPARAM	_IOW (ZT_CODE, 58, struct zt_radio_param)
+/* Get a channel parameter IOCTL */
+#define	ZT_RADIO_GETPARAM	_IOR (ZT_CODE, 59, struct zt_radio_param)
+
+
+/* Defines for Radio Status (zt_radio_stat.radstat) bits */
+
+#define	ZT_RADSTAT_RX	1	/* currently "receiving " */
+#define	ZT_RADSTAT_TX	2	/* currently "transmitting" */
+#define	ZT_RADSTAT_RXCT	4	/* currently receiving continuous tone with 
+				   current settings */
+#define	ZT_RADSTAT_RXCOR	8	/* currently receiving COR (irrelevant of COR
+				   ignore) */
+#define	ZT_RADSTAT_IGNCOR	16	/* currently ignoring COR */
+#define	ZT_RADSTAT_IGNCT	32	/* currently ignoring CTCSS/DCS decode */
+#define	ZT_RADSTAT_NOENCODE 64	/* currently blocking CTCSS/DCS encode */
+
+/* Defines for Radio Parameters (zt_radio_param.radpar) */
+
+#define	ZT_RADPAR_INVERTCOR 1	/* invert the COR signal (0/1) */
+#define	ZT_RADPAR_IGNORECOR 2	/* ignore the COR signal (0/1) */
+#define	ZT_RADPAR_IGNORECT 3	/* ignore the CTCSS/DCS decode (0/1) */
+#define	ZT_RADPAR_NOENCODE 4	/* block the CTCSS/DCS encode (0/1) */
+#define	ZT_RADPAR_CORTHRESH 5	/* COR trigger threshold (0-7) */
+
+#define	ZT_RADPAR_EXTRXTONE 6	/* 0 means use internal decoder, 1 means UIOA
+				   logic true is CT decode, 2 means UIOA logic
+				   false is CT decode */
+#define	ZT_RADPAR_NUMTONES	7	/* returns maximum tone index (curently 15) */
+#define	ZT_RADPAR_INITTONE	8	/* init all tone indexes to 0 (no tones) */
+#define	ZT_RADPAR_RXTONE	9	/* CTCSS tone, (1-32) or DCS tone (1-777),
+				   or 0 meaning no tone, set index also (1-15) */
+#define	ZT_RADPAR_RXTONECLASS 10	/* Tone class (0-65535), set index also (1-15) */
+#define	ZT_RADPAR_TXTONE 11	/* CTCSS tone (1-32) or DCS tone (1-777) or 0
+				   to indicate no tone, to transmit 
+				   for this tone index (0-32, 0 disables
+				   transmit CTCSS), set index also (0-15) */
+#define	ZT_RADPAR_DEBOUNCETIME 12	/* receive indication debounce time, 
+				   milliseconds (1-999) */
+#define	ZT_RADPAR_BURSTTIME 13	/* end of transmit with no CT tone in
+				   milliseconds (0-999) */
+
+
+#define	ZT_RADPAR_UIODATA 14	/* read/write UIOA and UIOB data. Bit 0 is
+				   UIOA, bit 1 is UIOB */
+#define	ZT_RADPAR_UIOMODE 15	/* 0 means UIOA and UIOB are both outputs, 1
+				   means UIOA is input, UIOB is output, 2 
+				   means UIOB is input and UIOA is output,
+				   3 means both UIOA and UIOB are inputs. Note
+				   mode for UIOA is overridden when in
+				   EXTRXTONE mode. */
+
+#define	ZT_RADPAR_REMMODE 16	/* Remote control data mode */
+	#define	ZT_RADPAR_REM_NONE 0 	/* no remote control data mode */
+	#define	ZT_RADPAR_REM_RBI1 1	/* Doug Hall RBI-1 data mode */
+	#define	ZT_RADPAR_REM_SERIAL 2	/* Serial Data, 9600 BPS */
+	#define	ZT_RADPAR_REM_SERIAL_ASCII 3	/* Serial Ascii Data, 9600 BPS */
+
+#define	ZT_RADPAR_REMCOMMAND 17	/* Remote conrtol write data block & do cmd */
+
+
 #endif /* _LINUX_ZAPTEL_H */
